"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class GetOnlineRankReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    RUID_FIELD_NUMBER: builtins.int
    ROOM_ID_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PLATFORM_FIELD_NUMBER: builtins.int
    ruid: builtins.int
    """"""

    room_id: builtins.int
    """"""

    page: builtins.int
    """"""

    page_size: builtins.int
    """"""

    platform: typing.Text
    """"""

    def __init__(self,
        *,
        ruid: builtins.int = ...,
        room_id: builtins.int = ...,
        page: builtins.int = ...,
        page_size: builtins.int = ...,
        platform: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["page",b"page","page_size",b"page_size","platform",b"platform","room_id",b"room_id","ruid",b"ruid"]) -> None: ...
global___GetOnlineRankReq = GetOnlineRankReq

class GetOnlineRankResp(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class OnlineRankItem(google.protobuf.message.Message):
        """"""
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        UID_FIELD_NUMBER: builtins.int
        UNAME_FIELD_NUMBER: builtins.int
        FACE_FIELD_NUMBER: builtins.int
        CONTINUE_WATCH_FIELD_NUMBER: builtins.int
        MEDAL_INFO_FIELD_NUMBER: builtins.int
        GUARD_LEVEL_FIELD_NUMBER: builtins.int
        uid: builtins.int
        """"""

        uname: typing.Text
        """"""

        face: typing.Text
        """"""

        continue_watch: builtins.int
        """"""

        @property
        def medal_info(self) -> global___MedalInfo:
            """"""
            pass
        guard_level: builtins.int
        """"""

        def __init__(self,
            *,
            uid: builtins.int = ...,
            uname: typing.Text = ...,
            face: typing.Text = ...,
            continue_watch: builtins.int = ...,
            medal_info: typing.Optional[global___MedalInfo] = ...,
            guard_level: builtins.int = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["medal_info",b"medal_info"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["continue_watch",b"continue_watch","face",b"face","guard_level",b"guard_level","medal_info",b"medal_info","uid",b"uid","uname",b"uname"]) -> None: ...

    ITEM_FIELD_NUMBER: builtins.int
    ONLINE_NUM_FIELD_NUMBER: builtins.int
    @property
    def item(self) -> global___GetOnlineRankResp.OnlineRankItem:
        """"""
        pass
    online_num: builtins.int
    """"""

    def __init__(self,
        *,
        item: typing.Optional[global___GetOnlineRankResp.OnlineRankItem] = ...,
        online_num: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["item",b"item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["item",b"item","online_num",b"online_num"]) -> None: ...
global___GetOnlineRankResp = GetOnlineRankResp

class MedalInfo(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    GUARD_LEVEL_FIELD_NUMBER: builtins.int
    MEDAL_COLOR_START_FIELD_NUMBER: builtins.int
    MEDAL_COLOR_END_FIELD_NUMBER: builtins.int
    MEDAL_COLOR_BORDER_FIELD_NUMBER: builtins.int
    MEDAL_NAME_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    TARGET_ID_FIELD_NUMBER: builtins.int
    IS_LIGHT_FIELD_NUMBER: builtins.int
    guard_level: builtins.int
    """"""

    medal_color_start: builtins.int
    """"""

    medal_color_end: builtins.int
    """"""

    medal_color_border: builtins.int
    """"""

    medal_name: typing.Text
    """"""

    level: builtins.int
    """"""

    target_id: builtins.int
    """"""

    is_light: builtins.int
    """"""

    def __init__(self,
        *,
        guard_level: builtins.int = ...,
        medal_color_start: builtins.int = ...,
        medal_color_end: builtins.int = ...,
        medal_color_border: builtins.int = ...,
        medal_name: typing.Text = ...,
        level: builtins.int = ...,
        target_id: builtins.int = ...,
        is_light: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["guard_level",b"guard_level","is_light",b"is_light","level",b"level","medal_color_border",b"medal_color_border","medal_color_end",b"medal_color_end","medal_color_start",b"medal_color_start","medal_name",b"medal_name","target_id",b"target_id"]) -> None: ...
global___MedalInfo = MedalInfo



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/app/topic/v1/topic.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.app.dynamic.v2 import dynamic_pb2 as bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2
from bilireq.grpc.protos.bilibili.app.card.v1 import common_pb2 as bilibili_dot_app_dot_card_dot_v1_dot_common__pb2
from bilireq.grpc.protos.bilibili.app.archive.middleware.v1 import preload_pb2 as bilibili_dot_app_dot_archive_dot_middleware_dot_v1_dot_preload__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!bilibili/app/topic/v1/topic.proto\x12\x15\x62ilibili.app.topic.v1\x1a%bilibili/app/dynamic/v2/dynamic.proto\x1a!bilibili/app/card/v1/common.proto\x1a\x30\x62ilibili/app/archive/middleware/v1/preload.proto\"\xb0\x02\n\x0e\x44\x65tailsTopInfo\x12\x34\n\ntopic_info\x18\x01 \x01(\x0b\x32 .bilibili.app.topic.v1.TopicInfo\x12)\n\x04user\x18\x02 \x01(\x0b\x32\x1b.bilibili.app.topic.v1.User\x12\x12\n\nstats_desc\x18\x03 \x01(\t\x12\x1f\n\x17has_create_jurisdiction\x18\x04 \x01(\x08\x12\x42\n\x11operation_content\x18\x05 \x01(\x0b\x32\'.bilibili.app.topic.v1.OperationContent\x12\x14\n\x0chead_img_url\x18\x06 \x01(\t\x12\x1a\n\x12head_img_backcolor\x18\x07 \x01(\t\x12\x12\n\nword_color\x18\x08 \x01(\x05\"c\n\x0c\x46oldCardItem\x12\x14\n\x0cis_show_fold\x18\x01 \x01(\x05\x12\x12\n\nfold_count\x18\x02 \x01(\x03\x12\x16\n\x0e\x63\x61rd_show_desc\x18\x03 \x01(\t\x12\x11\n\tfold_desc\x18\x04 \x01(\t\"\xb5\x01\n\x0e\x46unctionalCard\x12\x35\n\x08\x63\x61psules\x18\x01 \x03(\x0b\x32#.bilibili.app.topic.v1.TopicCapsule\x12\x38\n\x0ctraffic_card\x18\x02 \x01(\x0b\x32\".bilibili.app.topic.v1.TrafficCard\x12\x32\n\tgame_card\x18\x03 \x01(\x0b\x32\x1f.bilibili.app.topic.v1.GameCard\"\x86\x01\n\x08GameCard\x12\x0f\n\x07game_id\x18\x01 \x01(\x03\x12\x11\n\tgame_icon\x18\x02 \x01(\t\x12\x11\n\tgame_name\x18\x03 \x01(\t\x12\r\n\x05score\x18\x04 \x01(\t\x12\x11\n\tgame_tags\x18\x05 \x01(\t\x12\x0e\n\x06notice\x18\x06 \x01(\t\x12\x11\n\tgame_link\x18\x07 \x01(\t\"i\n\x11InlineProgressBar\x12\x11\n\ticon_drag\x18\x01 \x01(\t\x12\x16\n\x0eicon_drag_hash\x18\x02 \x01(\t\x12\x11\n\ticon_stop\x18\x03 \x01(\t\x12\x16\n\x0eicon_stop_hash\x18\x04 \x01(\t\"\xb9\x04\n\x10LargeCoverInline\x12(\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Base\x12\x18\n\x10\x63over_left_text1\x18\x02 \x01(\t\x12\x18\n\x10\x63over_left_icon1\x18\x03 \x01(\x05\x12\x18\n\x10\x63over_left_text2\x18\x04 \x01(\t\x12\x18\n\x10\x63over_left_icon2\x18\x05 \x01(\x05\x12\x46\n\x14right_top_live_badge\x18\x06 \x01(\x0b\x32(.bilibili.app.topic.v1.RightTopLiveBadge\x12\x11\n\textra_uri\x18\x07 \x01(\t\x12\x45\n\x13inline_progress_bar\x18\x08 \x01(\x0b\x32(.bilibili.app.topic.v1.InlineProgressBar\x12\x41\n\x11topic_three_point\x18\t \x01(\x0b\x32&.bilibili.app.topic.v1.TopicThreePoint\x12\x17\n\x0f\x63over_left_desc\x18\n \x01(\t\x12\x19\n\x11hide_danmu_switch\x18\x0b \x01(\x08\x12\x15\n\rdisable_danmu\x18\x0c \x01(\x08\x12\x10\n\x08\x63\x61n_play\x18\r \x01(\x05\x12\x15\n\rduration_text\x18\x0e \x01(\t\x12:\n\rrelation_data\x18\x0f \x01(\x0b\x32#.bilibili.app.topic.v1.RelationData\"\xd2\x01\n\x11LiveBadgeResource\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x15\n\ranimation_url\x18\x02 \x01(\t\x12\x1a\n\x12\x61nimation_url_hash\x18\x03 \x01(\t\x12\x1e\n\x16\x62\x61\x63kground_color_light\x18\x04 \x01(\t\x12\x1e\n\x16\x62\x61\x63kground_color_night\x18\x05 \x01(\t\x12\x13\n\x0b\x61lpha_light\x18\x06 \x01(\x03\x12\x13\n\x0b\x61lpha_night\x18\x07 \x01(\x03\x12\x12\n\nfont_color\x18\x08 \x01(\t\"^\n\rOperationCard\x12\x45\n\x12large_cover_inline\x18\x01 \x01(\x0b\x32\'.bilibili.app.topic.v1.LargeCoverInlineH\x00\x42\x06\n\x04\x63\x61rd\"P\n\x10OperationContent\x12<\n\x0eoperation_card\x18\x01 \x01(\x0b\x32$.bilibili.app.topic.v1.OperationCard\"g\n\x0cRelationData\x12\x0e\n\x06is_fav\x18\x01 \x01(\x08\x12\x0f\n\x07is_coin\x18\x02 \x01(\x08\x12\x11\n\tis_follow\x18\x03 \x01(\x08\x12\x0f\n\x07is_like\x18\x04 \x01(\x08\x12\x12\n\nlike_count\x18\x05 \x01(\x03\"|\n\x11RightTopLiveBadge\x12\x13\n\x0blive_status\x18\x01 \x01(\x03\x12\x39\n\x07in_live\x18\x02 \x01(\x0b\x32(.bilibili.app.topic.v1.LiveBadgeResource\x12\x17\n\x0flive_stats_desc\x18\x03 \x01(\t\"1\n\x0bSortContent\x12\x0f\n\x07sort_by\x18\x01 \x01(\x03\x12\x11\n\tsort_name\x18\x02 \x01(\t\"1\n\x0eThreePointItem\x12\r\n\x05title\x18\x01 \x01(\t\x12\x10\n\x08jump_url\x18\x02 \x01(\t\"a\n\x0fTopicActivities\x12\x36\n\x08\x61\x63tivity\x18\x01 \x03(\x0b\x32$.bilibili.app.topic.v1.TopicActivity\x12\x16\n\x0e\x61\x63t_list_title\x18\x02 \x01(\t\"_\n\rTopicActivity\x12\x13\n\x0b\x61\x63tivity_id\x18\x01 \x01(\x03\x12\x15\n\ractivity_name\x18\x02 \x01(\t\x12\x10\n\x08jump_url\x18\x03 \x01(\t\x12\x10\n\x08icon_url\x18\x04 \x01(\t\"@\n\x0cTopicCapsule\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08jump_url\x18\x02 \x01(\t\x12\x10\n\x08icon_url\x18\x03 \x01(\t\"\x96\x01\n\rTopicCardItem\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12:\n\x0c\x64ynamic_item\x18\x02 \x01(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\x12;\n\x0e\x66ord_card_item\x18\x03 \x01(\x0b\x32#.bilibili.app.topic.v1.FoldCardItem\"\xb5\x01\n\rTopicCardList\x12>\n\x10topic_card_items\x18\x01 \x03(\x0b\x32$.bilibili.app.topic.v1.TopicCardItem\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x10\n\x08has_more\x18\x03 \x01(\x08\x12\x42\n\x12topic_sort_by_conf\x18\x04 \x01(\x0b\x32&.bilibili.app.topic.v1.TopicSortByConf\"\x98\x02\n\x14TopicDetailsAllReply\x12?\n\x10\x64\x65tails_top_info\x18\x01 \x01(\x0b\x32%.bilibili.app.topic.v1.DetailsTopInfo\x12@\n\x10topic_activities\x18\x02 \x01(\x0b\x32&.bilibili.app.topic.v1.TopicActivities\x12=\n\x0ftopic_card_list\x18\x03 \x01(\x0b\x32$.bilibili.app.topic.v1.TopicCardList\x12>\n\x0f\x66unctional_card\x18\x04 \x01(\x0b\x32%.bilibili.app.topic.v1.FunctionalCard\"\xd9\x01\n\x12TopicDetailsAllReq\x12\x10\n\x08topic_id\x18\x01 \x01(\x03\x12\x0f\n\x07sort_by\x18\x02 \x01(\x03\x12\x0e\n\x06offset\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05\x12\x12\n\nlocal_time\x18\x05 \x01(\x05\x12\x43\n\x0bplayer_args\x18\x06 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x14\n\x0cneed_refresh\x18\x07 \x01(\x05\x12\x0e\n\x06source\x18\x08 \x01(\t\"j\n\x15TopicDetailsFoldReply\x12=\n\x0ftopic_card_list\x18\x01 \x01(\x0b\x32$.bilibili.app.topic.v1.TopicCardList\x12\x12\n\nfold_count\x18\x02 \x01(\x03\"\xb9\x01\n\x13TopicDetailsFoldReq\x12\x10\n\x08topic_id\x18\x01 \x01(\x03\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\nlocal_time\x18\x04 \x01(\x05\x12\x43\n\x0bplayer_args\x18\x05 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x14\n\x0c\x66rom_sort_by\x18\x06 \x01(\x03\"\xb4\x02\n\tTopicInfo\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03uid\x18\x03 \x01(\x03\x12\x0c\n\x04view\x18\x04 \x01(\x03\x12\x0f\n\x07\x64iscuss\x18\x05 \x01(\x03\x12\x0b\n\x03\x66\x61v\x18\x06 \x01(\x03\x12\x10\n\x08\x64ynamics\x18\x07 \x01(\x03\x12\r\n\x05state\x18\x08 \x01(\x05\x12\x10\n\x08jump_url\x18\t \x01(\t\x12\x11\n\tbackcolor\x18\n \x01(\t\x12\x0e\n\x06is_fav\x18\x0b \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x0c \x01(\t\x12\x15\n\rcreate_source\x18\r \x01(\x05\x12\x11\n\tshare_pic\x18\x0e \x01(\t\x12\r\n\x05share\x18\x0f \x01(\x03\x12\x0c\n\x04like\x18\x10 \x01(\x03\x12\x11\n\tshare_url\x18\x11 \x01(\t\x12\x0f\n\x07is_like\x18\x12 \x01(\x08\"y\n\x0fTopicSortByConf\x12\x17\n\x0f\x64\x65\x66\x61ult_sort_by\x18\x01 \x01(\x03\x12\x37\n\x0b\x61ll_sort_by\x18\x02 \x03(\x0b\x32\".bilibili.app.topic.v1.SortContent\x12\x14\n\x0cshow_sort_by\x18\x03 \x01(\x03\"W\n\x0fTopicThreePoint\x12\x44\n\x15\x64yn_three_point_items\x18\x01 \x03(\x0b\x32%.bilibili.app.topic.v1.ThreePointItem\"\x8f\x01\n\x0bTrafficCard\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08jump_url\x18\x02 \x01(\t\x12\x10\n\x08icon_url\x18\x03 \x01(\t\x12\x10\n\x08\x62\x61se_pic\x18\x04 \x01(\t\x12\x15\n\rbenefit_point\x18\x05 \x01(\t\x12\x11\n\tcard_desc\x18\x06 \x01(\t\x12\x12\n\njump_title\x18\x07 \x01(\t\"B\n\x04User\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x0c\n\x04\x66\x61\x63\x65\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x11\n\tname_desc\x18\x04 \x01(\t*8\n\rTopicCardType\x12\x10\n\x0cILLEGAL_TYPE\x10\x00\x12\x0b\n\x07\x44YNAMIC\x10\x01\x12\x08\n\x04\x46OLD\x10\x02\x32\xe0\x01\n\x05Topic\x12i\n\x0fTopicDetailsAll\x12).bilibili.app.topic.v1.TopicDetailsAllReq\x1a+.bilibili.app.topic.v1.TopicDetailsAllReply\x12l\n\x10TopicDetailsFold\x12*.bilibili.app.topic.v1.TopicDetailsFoldReq\x1a,.bilibili.app.topic.v1.TopicDetailsFoldReplyb\x06proto3')

_TOPICCARDTYPE = DESCRIPTOR.enum_types_by_name['TopicCardType']
TopicCardType = enum_type_wrapper.EnumTypeWrapper(_TOPICCARDTYPE)
ILLEGAL_TYPE = 0
DYNAMIC = 1
FOLD = 2


_DETAILSTOPINFO = DESCRIPTOR.message_types_by_name['DetailsTopInfo']
_FOLDCARDITEM = DESCRIPTOR.message_types_by_name['FoldCardItem']
_FUNCTIONALCARD = DESCRIPTOR.message_types_by_name['FunctionalCard']
_GAMECARD = DESCRIPTOR.message_types_by_name['GameCard']
_INLINEPROGRESSBAR = DESCRIPTOR.message_types_by_name['InlineProgressBar']
_LARGECOVERINLINE = DESCRIPTOR.message_types_by_name['LargeCoverInline']
_LIVEBADGERESOURCE = DESCRIPTOR.message_types_by_name['LiveBadgeResource']
_OPERATIONCARD = DESCRIPTOR.message_types_by_name['OperationCard']
_OPERATIONCONTENT = DESCRIPTOR.message_types_by_name['OperationContent']
_RELATIONDATA = DESCRIPTOR.message_types_by_name['RelationData']
_RIGHTTOPLIVEBADGE = DESCRIPTOR.message_types_by_name['RightTopLiveBadge']
_SORTCONTENT = DESCRIPTOR.message_types_by_name['SortContent']
_THREEPOINTITEM = DESCRIPTOR.message_types_by_name['ThreePointItem']
_TOPICACTIVITIES = DESCRIPTOR.message_types_by_name['TopicActivities']
_TOPICACTIVITY = DESCRIPTOR.message_types_by_name['TopicActivity']
_TOPICCAPSULE = DESCRIPTOR.message_types_by_name['TopicCapsule']
_TOPICCARDITEM = DESCRIPTOR.message_types_by_name['TopicCardItem']
_TOPICCARDLIST = DESCRIPTOR.message_types_by_name['TopicCardList']
_TOPICDETAILSALLREPLY = DESCRIPTOR.message_types_by_name['TopicDetailsAllReply']
_TOPICDETAILSALLREQ = DESCRIPTOR.message_types_by_name['TopicDetailsAllReq']
_TOPICDETAILSFOLDREPLY = DESCRIPTOR.message_types_by_name['TopicDetailsFoldReply']
_TOPICDETAILSFOLDREQ = DESCRIPTOR.message_types_by_name['TopicDetailsFoldReq']
_TOPICINFO = DESCRIPTOR.message_types_by_name['TopicInfo']
_TOPICSORTBYCONF = DESCRIPTOR.message_types_by_name['TopicSortByConf']
_TOPICTHREEPOINT = DESCRIPTOR.message_types_by_name['TopicThreePoint']
_TRAFFICCARD = DESCRIPTOR.message_types_by_name['TrafficCard']
_USER = DESCRIPTOR.message_types_by_name['User']
DetailsTopInfo = _reflection.GeneratedProtocolMessageType('DetailsTopInfo', (_message.Message,), {
  'DESCRIPTOR' : _DETAILSTOPINFO,
  '__module__' : 'bilibili.app.topic.v1.topic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.topic.v1.DetailsTopInfo)
  })
_sym_db.RegisterMessage(DetailsTopInfo)

FoldCardItem = _reflection.GeneratedProtocolMessageType('FoldCardItem', (_message.Message,), {
  'DESCRIPTOR' : _FOLDCARDITEM,
  '__module__' : 'bilibili.app.topic.v1.topic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.topic.v1.FoldCardItem)
  })
_sym_db.RegisterMessage(FoldCardItem)

FunctionalCard = _reflection.GeneratedProtocolMessageType('FunctionalCard', (_message.Message,), {
  'DESCRIPTOR' : _FUNCTIONALCARD,
  '__module__' : 'bilibili.app.topic.v1.topic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.topic.v1.FunctionalCard)
  })
_sym_db.RegisterMessage(FunctionalCard)

GameCard = _reflection.GeneratedProtocolMessageType('GameCard', (_message.Message,), {
  'DESCRIPTOR' : _GAMECARD,
  '__module__' : 'bilibili.app.topic.v1.topic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.topic.v1.GameCard)
  })
_sym_db.RegisterMessage(GameCard)

InlineProgressBar = _reflection.GeneratedProtocolMessageType('InlineProgressBar', (_message.Message,), {
  'DESCRIPTOR' : _INLINEPROGRESSBAR,
  '__module__' : 'bilibili.app.topic.v1.topic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.topic.v1.InlineProgressBar)
  })
_sym_db.RegisterMessage(InlineProgressBar)

LargeCoverInline = _reflection.GeneratedProtocolMessageType('LargeCoverInline', (_message.Message,), {
  'DESCRIPTOR' : _LARGECOVERINLINE,
  '__module__' : 'bilibili.app.topic.v1.topic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.topic.v1.LargeCoverInline)
  })
_sym_db.RegisterMessage(LargeCoverInline)

LiveBadgeResource = _reflection.GeneratedProtocolMessageType('LiveBadgeResource', (_message.Message,), {
  'DESCRIPTOR' : _LIVEBADGERESOURCE,
  '__module__' : 'bilibili.app.topic.v1.topic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.topic.v1.LiveBadgeResource)
  })
_sym_db.RegisterMessage(LiveBadgeResource)

OperationCard = _reflection.GeneratedProtocolMessageType('OperationCard', (_message.Message,), {
  'DESCRIPTOR' : _OPERATIONCARD,
  '__module__' : 'bilibili.app.topic.v1.topic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.topic.v1.OperationCard)
  })
_sym_db.RegisterMessage(OperationCard)

OperationContent = _reflection.GeneratedProtocolMessageType('OperationContent', (_message.Message,), {
  'DESCRIPTOR' : _OPERATIONCONTENT,
  '__module__' : 'bilibili.app.topic.v1.topic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.topic.v1.OperationContent)
  })
_sym_db.RegisterMessage(OperationContent)

RelationData = _reflection.GeneratedProtocolMessageType('RelationData', (_message.Message,), {
  'DESCRIPTOR' : _RELATIONDATA,
  '__module__' : 'bilibili.app.topic.v1.topic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.topic.v1.RelationData)
  })
_sym_db.RegisterMessage(RelationData)

RightTopLiveBadge = _reflection.GeneratedProtocolMessageType('RightTopLiveBadge', (_message.Message,), {
  'DESCRIPTOR' : _RIGHTTOPLIVEBADGE,
  '__module__' : 'bilibili.app.topic.v1.topic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.topic.v1.RightTopLiveBadge)
  })
_sym_db.RegisterMessage(RightTopLiveBadge)

SortContent = _reflection.GeneratedProtocolMessageType('SortContent', (_message.Message,), {
  'DESCRIPTOR' : _SORTCONTENT,
  '__module__' : 'bilibili.app.topic.v1.topic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.topic.v1.SortContent)
  })
_sym_db.RegisterMessage(SortContent)

ThreePointItem = _reflection.GeneratedProtocolMessageType('ThreePointItem', (_message.Message,), {
  'DESCRIPTOR' : _THREEPOINTITEM,
  '__module__' : 'bilibili.app.topic.v1.topic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.topic.v1.ThreePointItem)
  })
_sym_db.RegisterMessage(ThreePointItem)

TopicActivities = _reflection.GeneratedProtocolMessageType('TopicActivities', (_message.Message,), {
  'DESCRIPTOR' : _TOPICACTIVITIES,
  '__module__' : 'bilibili.app.topic.v1.topic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.topic.v1.TopicActivities)
  })
_sym_db.RegisterMessage(TopicActivities)

TopicActivity = _reflection.GeneratedProtocolMessageType('TopicActivity', (_message.Message,), {
  'DESCRIPTOR' : _TOPICACTIVITY,
  '__module__' : 'bilibili.app.topic.v1.topic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.topic.v1.TopicActivity)
  })
_sym_db.RegisterMessage(TopicActivity)

TopicCapsule = _reflection.GeneratedProtocolMessageType('TopicCapsule', (_message.Message,), {
  'DESCRIPTOR' : _TOPICCAPSULE,
  '__module__' : 'bilibili.app.topic.v1.topic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.topic.v1.TopicCapsule)
  })
_sym_db.RegisterMessage(TopicCapsule)

TopicCardItem = _reflection.GeneratedProtocolMessageType('TopicCardItem', (_message.Message,), {
  'DESCRIPTOR' : _TOPICCARDITEM,
  '__module__' : 'bilibili.app.topic.v1.topic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.topic.v1.TopicCardItem)
  })
_sym_db.RegisterMessage(TopicCardItem)

TopicCardList = _reflection.GeneratedProtocolMessageType('TopicCardList', (_message.Message,), {
  'DESCRIPTOR' : _TOPICCARDLIST,
  '__module__' : 'bilibili.app.topic.v1.topic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.topic.v1.TopicCardList)
  })
_sym_db.RegisterMessage(TopicCardList)

TopicDetailsAllReply = _reflection.GeneratedProtocolMessageType('TopicDetailsAllReply', (_message.Message,), {
  'DESCRIPTOR' : _TOPICDETAILSALLREPLY,
  '__module__' : 'bilibili.app.topic.v1.topic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.topic.v1.TopicDetailsAllReply)
  })
_sym_db.RegisterMessage(TopicDetailsAllReply)

TopicDetailsAllReq = _reflection.GeneratedProtocolMessageType('TopicDetailsAllReq', (_message.Message,), {
  'DESCRIPTOR' : _TOPICDETAILSALLREQ,
  '__module__' : 'bilibili.app.topic.v1.topic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.topic.v1.TopicDetailsAllReq)
  })
_sym_db.RegisterMessage(TopicDetailsAllReq)

TopicDetailsFoldReply = _reflection.GeneratedProtocolMessageType('TopicDetailsFoldReply', (_message.Message,), {
  'DESCRIPTOR' : _TOPICDETAILSFOLDREPLY,
  '__module__' : 'bilibili.app.topic.v1.topic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.topic.v1.TopicDetailsFoldReply)
  })
_sym_db.RegisterMessage(TopicDetailsFoldReply)

TopicDetailsFoldReq = _reflection.GeneratedProtocolMessageType('TopicDetailsFoldReq', (_message.Message,), {
  'DESCRIPTOR' : _TOPICDETAILSFOLDREQ,
  '__module__' : 'bilibili.app.topic.v1.topic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.topic.v1.TopicDetailsFoldReq)
  })
_sym_db.RegisterMessage(TopicDetailsFoldReq)

TopicInfo = _reflection.GeneratedProtocolMessageType('TopicInfo', (_message.Message,), {
  'DESCRIPTOR' : _TOPICINFO,
  '__module__' : 'bilibili.app.topic.v1.topic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.topic.v1.TopicInfo)
  })
_sym_db.RegisterMessage(TopicInfo)

TopicSortByConf = _reflection.GeneratedProtocolMessageType('TopicSortByConf', (_message.Message,), {
  'DESCRIPTOR' : _TOPICSORTBYCONF,
  '__module__' : 'bilibili.app.topic.v1.topic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.topic.v1.TopicSortByConf)
  })
_sym_db.RegisterMessage(TopicSortByConf)

TopicThreePoint = _reflection.GeneratedProtocolMessageType('TopicThreePoint', (_message.Message,), {
  'DESCRIPTOR' : _TOPICTHREEPOINT,
  '__module__' : 'bilibili.app.topic.v1.topic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.topic.v1.TopicThreePoint)
  })
_sym_db.RegisterMessage(TopicThreePoint)

TrafficCard = _reflection.GeneratedProtocolMessageType('TrafficCard', (_message.Message,), {
  'DESCRIPTOR' : _TRAFFICCARD,
  '__module__' : 'bilibili.app.topic.v1.topic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.topic.v1.TrafficCard)
  })
_sym_db.RegisterMessage(TrafficCard)

User = _reflection.GeneratedProtocolMessageType('User', (_message.Message,), {
  'DESCRIPTOR' : _USER,
  '__module__' : 'bilibili.app.topic.v1.topic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.topic.v1.User)
  })
_sym_db.RegisterMessage(User)

_TOPIC = DESCRIPTOR.services_by_name['Topic']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TOPICCARDTYPE._serialized_start=4451
  _TOPICCARDTYPE._serialized_end=4507
  _DETAILSTOPINFO._serialized_start=185
  _DETAILSTOPINFO._serialized_end=489
  _FOLDCARDITEM._serialized_start=491
  _FOLDCARDITEM._serialized_end=590
  _FUNCTIONALCARD._serialized_start=593
  _FUNCTIONALCARD._serialized_end=774
  _GAMECARD._serialized_start=777
  _GAMECARD._serialized_end=911
  _INLINEPROGRESSBAR._serialized_start=913
  _INLINEPROGRESSBAR._serialized_end=1018
  _LARGECOVERINLINE._serialized_start=1021
  _LARGECOVERINLINE._serialized_end=1590
  _LIVEBADGERESOURCE._serialized_start=1593
  _LIVEBADGERESOURCE._serialized_end=1803
  _OPERATIONCARD._serialized_start=1805
  _OPERATIONCARD._serialized_end=1899
  _OPERATIONCONTENT._serialized_start=1901
  _OPERATIONCONTENT._serialized_end=1981
  _RELATIONDATA._serialized_start=1983
  _RELATIONDATA._serialized_end=2086
  _RIGHTTOPLIVEBADGE._serialized_start=2088
  _RIGHTTOPLIVEBADGE._serialized_end=2212
  _SORTCONTENT._serialized_start=2214
  _SORTCONTENT._serialized_end=2263
  _THREEPOINTITEM._serialized_start=2265
  _THREEPOINTITEM._serialized_end=2314
  _TOPICACTIVITIES._serialized_start=2316
  _TOPICACTIVITIES._serialized_end=2413
  _TOPICACTIVITY._serialized_start=2415
  _TOPICACTIVITY._serialized_end=2510
  _TOPICCAPSULE._serialized_start=2512
  _TOPICCAPSULE._serialized_end=2576
  _TOPICCARDITEM._serialized_start=2579
  _TOPICCARDITEM._serialized_end=2729
  _TOPICCARDLIST._serialized_start=2732
  _TOPICCARDLIST._serialized_end=2913
  _TOPICDETAILSALLREPLY._serialized_start=2916
  _TOPICDETAILSALLREPLY._serialized_end=3196
  _TOPICDETAILSALLREQ._serialized_start=3199
  _TOPICDETAILSALLREQ._serialized_end=3416
  _TOPICDETAILSFOLDREPLY._serialized_start=3418
  _TOPICDETAILSFOLDREPLY._serialized_end=3524
  _TOPICDETAILSFOLDREQ._serialized_start=3527
  _TOPICDETAILSFOLDREQ._serialized_end=3712
  _TOPICINFO._serialized_start=3715
  _TOPICINFO._serialized_end=4023
  _TOPICSORTBYCONF._serialized_start=4025
  _TOPICSORTBYCONF._serialized_end=4146
  _TOPICTHREEPOINT._serialized_start=4148
  _TOPICTHREEPOINT._serialized_end=4235
  _TRAFFICCARD._serialized_start=4238
  _TRAFFICCARD._serialized_end=4381
  _USER._serialized_start=4383
  _USER._serialized_end=4449
  _TOPIC._serialized_start=4510
  _TOPIC._serialized_end=4734
# @@protoc_insertion_point(module_scope)
